@@ -1,7 +1,7 @@
 /*
 
    xlog - GTK+ logging program for amateur radio operators
-   Copyright (C) 2001 - 2008 Joop Stakenborg <pg4i@amsat.org>
+   Copyright (C) 2001 - 2010 Joop Stakenborg <pg4i@amsat.org>
 
    This file is part of xlog.
 
@@ -64,7 +64,7 @@ flog_open (LOGDB * handle)
 {
 	FILE *fp;
 	gint column_nr = 0;
-	gchar *p, *field_name;
+	gchar *p, *field_name, *result;
 	gint field_width = 0;
 	gint in_space_state = 0;
 	gchar header_line[FLOG_MAX_LINE_SIZE];
@@ -74,8 +74,8 @@ flog_open (LOGDB * handle)
 		return -1;
 	handle->priv = (gpointer) fp;
 
-	fgets (header_line, FLOG_MAX_LINE_SIZE, fp);
-
+	result = fgets (header_line, FLOG_MAX_LINE_SIZE, fp);
+	
 	/* error handling */
 	if (strlen (header_line) < 80)
 	{
@@ -192,7 +192,7 @@ flog_qso_foreach (LOGDB * handle, gint (*fn) (LOGDB *, qso_t *, gpointer arg),
 	FILE *fp = (gpointer) handle->priv;
 	gint i, width, ret;
 	qso_t *q;
-	gchar buffer[MAX_VARIABLE_LEN];
+	gchar buffer[MAX_VARIABLE_LEN], *result;
 
 
 	while (!feof (fp))
@@ -202,13 +202,13 @@ flog_qso_foreach (LOGDB * handle, gint (*fn) (LOGDB *, qso_t *, gpointer arg),
 		for (i = 0; i < handle->column_nr - 1; i++)
 		{
 			width = handle->column_widths[i];
-			fgets (buffer, width, fp);
+			result = fgets (buffer, width, fp);
 			if (strlen (buffer) != width - 1 && i < handle->column_nr - 2)
 				return 0;		/* broken file */
 			q[handle->column_fields[i]] = g_strdup (g_strstrip (buffer));
 		}
 		/* last field */
-		fgets (buffer, MAX_VARIABLE_LEN, fp);
+		result = fgets (buffer, MAX_VARIABLE_LEN, fp);
 		width = strlen (buffer);
 		/* chop off EOL */
 		if (width > 0 && buffer[width - 1] == '\n')
